| Package: |
| TurboNorm |
| Type: |
| Package |
| Version: |
| 1.7.2 |
| Date: |
| 2013-29-01 |
| License: |
| LGPL |
| LazyLoad: |
| yes |
This package contains an implementation of piecewise constant P-splines of Eilers and Marx (1996) that can be used for normalization of either single- or two-colour data. For two-colour data objects of type RGList from the limma package and MarrayRaw from the package marray can be normalized using the function pspline(). For single colour microarray data wrapper functions are written based on the affy package functions normalize.loess() and normalize.AffyBatch.loess() namely normalize.pspline() and normalize.AffyBatch.pspline(). Also a panel.pspline() is available for adding the smoothed curve to lattice graphics panels.
Paul .H.C. Eilers and Brain D. Marx (1996). Flexible smoothing with B-splines and Penalties. Statistical Science, Vol 11, No. 2, 89-121.
turbotrend, pspline, normalize.pspline, normalize.AffyBatch.pspline, panel.pspline