Learn R Programming

TurboNorm (version 1.20.0)

pspline: Function for two-colour microarray data normalization using the P-splines

Description

Wrapper function for two colour microarray data normalization using the P-spline smoother suitable for a RGList- or MarrayRaw-objects.

Usage

pspline(object, background = c("none", "substract"), weights = NULL, nintervals = 100, subset=NULL, showArrays = 0, verbose=FALSE, line.col=2, line.lty=1, line.lwd=2, ...)

Arguments

object
either a RGList or an MarrayRaw-object.
background
for background substraction use 'substract'. Default is no backgroud substraction.
weights
vector of weights that will be used a for a weighted normalization. The default NULL assumse equal weight 1 for all data points.
nintervals
number of bins in which the data will be divided. The default is 100 bins.
showArrays
either a integer( > 0) or a vector of integers indicating the arrays for which a MA-plot will be produced.
subset
subset of the data on which the normalization will be based. A special case of weighted normalization.
verbose
if TRUE gives additional information on the fit
line.col, line.lty, line.lwd
line colour, type and width that will be used in the plots, defaults are col=2, lty=1 and lwd=2.
...
additional graphical arguments for plotting.

Value

The value that will be returned is either a MAList or MarrayNorm-object dependening on the input type.

Details

if necessary?

References

van Iterson M, Duijkers FA, Meijerink JP, Admiraal P, van Ommen GJ, Boer JM, van Noesel MM, Menezes RX (2012). A novel and fast normalization method for high-density arrays. SAGMB, 11(4).

Paul .H.C. Eilers and Brain D. Marx (1996). Flexible smoothing with B-splines and Penalties. Statistical Science, Vol 11, No. 2, 89-121.

See Also

normalizeWithinArrays, maNormMain

Examples

Run this code

library(marray)
data(swirl)

x <- pspline(swirl, showArrays=2, pch=20, col="grey")
x <- pspline(swirl, showArrays=2:4, line.col="green")

Run the code above in your browser using DataLab