Usage
pspline(object, background = c("none", "substract"), weights = NULL, nintervals = 100, subset=NULL, showArrays = 0, verbose=FALSE, line.col=2, line.lty=1, line.lwd=2, ...)
Arguments
object
either a RGList or an MarrayRaw-object.
background
for background substraction use 'substract'. Default is no backgroud substraction.
weights
vector of weights that will be used a for a weighted normalization. The default NULL assumse equal weight 1 for all data points.
nintervals
number of bins in which the data will be divided. The default is 100 bins.
showArrays
either a integer( > 0) or a vector of integers indicating the arrays for which a MA-plot will be produced.
subset
subset of the data on which the normalization will be based. A special case of weighted normalization.
verbose
if TRUE gives additional information on the fit
line.col, line.lty, line.lwd
line colour, type and width that will be used in the plots, defaults are col=2, lty=1 and lwd=2.
...
additional graphical arguments for plotting.